@@ -1,6 +1,6 @@
 # Copyright (C) 2003 by Dr. Dieter Maurer, Eichendorffstr. 23, D-66386 St. Ingbert, Germany
 # see "LICENSE.txt" for details
-#       $Id: ValueProvider.py,v 1.2 2008/07/29 11:34:22 dieter Exp $
+#       $Id: ValueProvider.py,v 1.3 2009/10/16 13:28:38 dieter Exp $
 '''ValueProvider.
 
 A 'ValueProvider' evaluates an object and returns a value.
@@ -17,8 +17,8 @@ and postprocessing should be handled. They can be ignored
 'ValueProviders' are 'SimpleItems' and provide comfiguration
 via Properties, i.e. they are 'PropertyManagers'.
 '''
+from zope.interface import implements
 
-from Globals import InitializeClass
 from AccessControl import ClassSecurityInfo
 from ComputedAttribute import ComputedAttribute
 from Acquisition import Acquired
@@ -32,9 +32,12 @@ from zope.tales.tales import CompilerError
 
 from Evaluation import EvalAndCall, Ignore, Normalize
 
+from interfaces import IPropertyManager
+
 
 class ValueProvider(SimpleItem,PropertyManager,Ignore,Normalize):
   '''configuration for object evaluation.'''
+  implements(IPropertyManager)
 
   manage_options= (
     PropertyManager.manage_options
@@ -82,6 +85,13 @@ class ValueProvider(SimpleItem,PropertyManager,Ignore,Normalize):
   def _evaluate(self,object):
     raise NotImplementedError("'_ValueProvider._evaluate' is abstract")
 
+# stupid Zope 2.12 compatibility
+try:
+  # new Zope 2.12 place
+  from App.class_init import InitializeClass
+except ImportError:
+  # try the old place
+  from Globals import InitializeClass
 InitializeClass(ValueProvider)
 
 
