@@ -1,6 +1,6 @@
 # Copyright (C) 2003 by Dr. Dieter Maurer, Eichendorffstr. 23, D-66386 St. Ingbert, Germany
 # see "LICENSE.txt" for details
-#       $Id: test_ManagableIndex.py,v 1.1.1.1 2008/06/28 16:03:50 dieter Exp $
+#       $Id: test_ManagableIndex.py,v 1.2 2009/07/08 12:00:10 dieter Exp $
 
 from TestBase import TestBase, genSuite, runSuite, TestCase
 
@@ -621,7 +621,7 @@ class TestProgrammaticSetup(TestCase):
     self.assertEqual(mi.TermTypeExtra, 'tte')
 
   def test_NoProvider(self):
-    mi = ManagableIndex('mi', {})
+    mi = ManagableIndex('mi', dict(ValueProviders=[]))
     self.assertEqual(mi.objectIds(), [])
 
   def test_ExpliciteProvidersWithProperties(self):
